package com.zhaoliangsz.grainsearch.service.impl;

import com.zhaoliangsz.grainsearch.domain.entity.InventoryTable;
import com.zhaoliangsz.grainsearch.mapper.InventoryTableMapper;
import com.zhaoliangsz.grainsearch.service.IInventoryTableService;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.stereotype.Service;
import com.zhaoliangsz.grainsearch.basic.exception.ServiceException;
import com.zhaoliangsz.grainsearch.basic.result.PageResult;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.springframework.transaction.annotation.Transactional;
import com.zhaoliangsz.grainsearch.basic.exception.ExceptionDefinition;
/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zyw
 * @since 2023-09-27 10:12:06
 */
@Slf4j
@Service
public class InventoryTableServiceImpl extends ServiceImpl<InventoryTableMapper, InventoryTable> implements IInventoryTableService {
    @Override
    public PageResult<InventoryTable> queryInventoryTableList(InventoryTable queryInventoryTable) throws ServiceException{
        try{
            Map<String,Object> pageView = new HashMap<>();
            pageView.put("startRecord",(queryInventoryTable.getCurrentPage()-1)
            *queryInventoryTable.getPageSize());
            pageView.put("pageSize",queryInventoryTable.getPageSize());
            pageView.put("currentPage",queryInventoryTable.getCurrentPage());
            Integer dataCount=baseMapper.getCountByCondition(pageView);
            List<InventoryTable>dataList=baseMapper.getListByCondition(pageView);
            return new PageResult<>(dataList==null?new ArrayList<>():dataList,dataCount==null?0:dataCount);
        }
        catch(Exception ex){
            log.error("[InventoryTableServiceImpl.queryInventoryTableList]异常:{}",ex.toString());
            throw new ServiceException(ExceptionDefinition.QUERY_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String addInventoryTable(InventoryTable addInventoryTable) throws ServiceException {
        boolean flag = this.save(addInventoryTable);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.ADD_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String editInventoryTable(InventoryTable editInventoryTable) throws ServiceException {
        boolean flag = this.updateById(editInventoryTable);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.EDIT_DATA_EXCEPTION);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String deleteInventoryTable(InventoryTable deleteInventoryTable) throws ServiceException {
        boolean flag = this.removeById(deleteInventoryTable);
        if(flag){
            return "ok";
        }
        else{
            throw new ServiceException(ExceptionDefinition.DELETE_DATA_EXCEPTION);
        }
    }
}
